* PROGRAM:      analysis.do
* AUTHOR:       Alex Fouirnaies, James Feigenbaum, Andy Hall
* INFILE:      MajorityMRD_NEW.dta
*************************************************************************

clear
program drop _all

/*********************************************
set the path
*********************************************/


** to run this locally, set the path global to the majority_advantage folder

local dir : pwd
if (regexm("`dir'", "feigenbaum")) {
	gl path = "C:/Users/jfeigenbaum/Dropbox/Research/majority_advantage/replication"
}
if (regexm("`dir'", "jjf")) {
	gl path = "D:/Dropbox/Research/majority_advantage/replication"
}
if (regexm("`dir'", "hall")) {
	gl path = "~/Dropbox/majority_advantage/replication"
}
if (regexm("`dir'", "alexander")) {
	gl path = "~/Dropbox/research/majority_advantage/replication"
}

cd "$path"

/*********************************************
NOTES ON OUTCOME VARIABLES:
Variables relating to outcome after NEXT ELECTION (regardless of whether it's 2 or 4 years downstreat):
	Dem's majority status in the House after NEXT ELECTION: dv1
 	Dem's share of the seats in the House after NEXT ELECTION: dv1_share
Variables relating to outcome two years downstream:
	House: dv1_demcontrolhouse, dv1_demhouseseatshare
	Senate: dv1_demsenateseatshare, dv1_demcontrolsenate
	Governor: dv1_demgov
Similarly: dv2_demcontrolhouse means the Dem's control the house 2 terms down stream (4 years later)
*********************************************/

/*********************************************
analysis requires rdrobust
*********************************************/

net install rdrobust, from(http://www-personal.umich.edu/~cattaneo/software/rdrobust/stata) replace

/*********************************************
Balance Tests to identify best distance metric (Table 1)
*********************************************/

use "MajorityMRD.dta", clear

foreach v in rv rve rvu {
	rdrobust lag_treat `v', c(0)
	local `v'_treat = e(tau_cl)
	local `v'_treat_se = e(se_tau_rb)
	local `v'_treat_n = e(N_h_l) + e(N_h_r)
	local `v'_treat_bw = e(h_l) + e(h_r)
	rdrobust lag_share `v', c(0)
	local `v'_share = e(tau_cl)
	local `v'_share_se = e(se_tau_rb)
	local `v'_share_n = e(N_h_l) + e(N_h_r)
	local `v'_share_bw = e(h_l) + e(h_r)
}

quietly {

set linesize 255

cap log close
	log using "output/balance_table.tex", text replace

	noisily display "\begin{table}[t]"
	noisily display "\centering"
	noisily display "\caption{\label{tab:balance}{\bf Balance Tests for Possible Distance Metrics.} Evaluates the performance of the three proposed"
	noisily display "distance metrics by testing for balance on lagged majority-party status and lagged seat share.  The Euclidean RV and the Uniform Swing RV perform best.}"
	noisily display "\begin{tabular}{lcccccc}"
	noisily display "\toprule \toprule"
	noisily display "& \multicolumn{2}{c}{RV=Manhattan} & \multicolumn{2}{c}{RV=Euclidean} & \multicolumn{2}{c}{RV=Uniform Swing} \\"
	noisily display " & Lag Majority & Lag Seat \% & Lag Majority & Lag Seat \% & Lag Majority & Lag Seat \% \\"
	noisily display "\midrule"
	noisily display " Dem Majority & " %4.2f `rv_treat' " & " %4.2f `rv_share' " & " %4.2f `rve_treat' " & " %4.2f `rve_share' " & " %4.2f `rvu_treat' " & " %4.2f `rvu_share' "\\"
	noisily display " & (" %4.2f `rv_treat_se' ") & (" %4.2f `rv_share_se' ") & (" %4.2f `rve_treat_se' ") & (" %4.2f `rve_share_se' ") & (" %4.2f `rvu_treat_se' ") & (" %4.2f `rvu_share_se' ") \\[2mm]"
	noisily display "Optimal BW & " %4.2f `rv_treat_bw' " & " %4.2f `rv_share_bw' " & " %4.2f `rve_treat_bw' " & " %4.2f `rve_share_bw' " & " %4.2f `rvu_treat_bw' " & " %4.2f `rvu_share_bw' "\\"
	noisily display "N & " %4.0f `rv_treat_n' " & " %4.0f `rv_share_n' " & " %4.0f `rve_treat_n' " & " %4.0f `rve_share_n' " & " %4.0f `rvu_treat_n' " & " %4.0f `rvu_share_n' "\\"
	noisily display "Specification & Local Linear & Local Linear & Local Linear & Local Linear & Local Linear & Local Linear \\"
	noisily display "\bottomrule \bottomrule\\[-4mm]"
	noisily display "\multicolumn{7}{p{1\textwidth}}{\footnotesize Estimates using \cite{calonico14} optimal bandwidth implemented with rdrobust in Stata.  Standard errors from this procedure in parentheses."
	noisily display "Bandwidth sizes are reported in the units of each running variable and therefore vary in magnitude across the three.}"
	noisily display "\end{tabular}"
	noisily display "\end{table}"

	log off


}

***why is seat share no good
foreach v in rvs {
	rdrobust lag_treat `v', c(0)
	local `v'_treat = e(tau_cl)
	local `v'_treat_se = e(se_tau_rb)
	local `v'_treat_n = e(N_h_l) + e(N_h_r)
	local `v'_treat_bw = e(h_l) + e(h_r)
	rdrobust lag_share `v', c(0)
	local `v'_share = e(tau_cl)
	local `v'_share_se = e(se_tau_rb)
	local `v'_share_n = e(N_h_l) + e(N_h_r)
	local `v'_share_bw = e(h_l) + e(h_r)
}

/*********************************************
Immediate effects
*********************************************/

rdrobust dv1_demcontrolhouse rve, c(0)
rdrobust dv1_demcontrolsenate rve,  c(0)
rdrobust dv1_demgov rve, c(0)

/*********************************************
Data for RD plots (Figure 3)
*********************************************/

use "MajorityMRD.dta", clear

forvalues j=1/10 {
	preserve
	keep if dv10_demcontrolhouse != .
	keep if abs(rve) < 20
	keep dv`j'_demcontrolhouse rve
	rename rve rv
	rename dv`j' dv
	saveold "temp/rdd_plot_win`j'.dta", replace
	restore
}

/*********************************************
Downstream analysis on HOUSE (Table 2)
*********************************************/

use "MajorityMRD.dta", clear

rdrobust dv1_demcontrolhouse rve, c(0)
local h = e(h_l) + e(h_r)

matrix B = J(10, 17, .)

keep if dv10_demcontrolhouse != .
keep if dv1_demcontrolhouse != .

forvalues j=1/10 {
	rdrobust dv`j'_demcontrolhouse rve, c(0)
	matrix B[`j', 1] = `j'
	matrix B[`j', 2] = e(tau_cl)
	matrix B[`j', 3] = e(tau_cl) - 1.96*e(se_tau_rb)
	matrix B[`j', 4] = e(tau_cl) + 1.96*e(se_tau_rb)
	local mrdn`j' = e(N_h_l) + e(N_h_r)
	xi: areg dv`j'_demcontrolhouse treat i.year, a(state) cluster(state)
	matrix B[`j', 5] = _b[treat]
	matrix B[`j', 6] = _b[treat] - 1.96*_se[treat]
	matrix B[`j', 7] = _b[treat] + 1.96*_se[treat]
	local diffn`j' = e(N)
	xi: areg dv`j'_demcontrolhouse treat i.year state_trend* year, a(state) cluster(state)
	matrix B[`j', 8] = _b[treat]
	matrix B[`j', 9] = _b[treat] - 1.96*_se[treat]
	matrix B[`j', 10] = _b[treat] + 1.96*_se[treat]
	local diffntrend`j' = e(N)
	rdrobust dv`j'_demhouseseatshare rve, c(0)
	matrix B[`j', 11] = `j'
	matrix B[`j', 12] = e(tau_cl)
	matrix B[`j', 13] = e(tau_cl) - 1.96*e(se_tau_rb)
	matrix B[`j', 14] = e(tau_cl) + 1.96*e(se_tau_rb)
	xi: areg dv`j'_demhouseseatshare treat state_trend* year i.year, a(state) cluster(state)
	matrix B[`j', 15] = _b[treat]
	matrix B[`j', 16] = _b[treat] - 1.96*_se[treat]
	matrix B[`j', 17] = _b[treat] + 1.96*_se[treat]
}

svmat B
keep B*
keep if B1 != .
saveold "temp/downstream_for_r.dta", replace

quietly {

set linesize 255

cap log close
	log using "output/mrd_table.tex", text replace

	noisily display "\begin{table}[p]"
	noisily display "\centering"
	noisily display "\caption{\label{tab:mrd}{\bf Effects of Majority-Party Status on Downstream Majority-Party Status.}"
	noisily display "Both the MRD and the Diff-in-Diff show a pronounced downstream disadvantage.}"
	noisily display "\begin{tabular}{lccc}"
	noisily display "\toprule \toprule"
	noisily display "Terms & MRD & Diff-in-Diff & Diff-in-Diff  \\"
	noisily display " Downstream & & & w/ Trends \\"
	noisily display "\midrule"
	forvalues j=1/10 {
		noisily display " $ k=`j' $ & " %4.2f B2[`j'] " & " %4.2f B5[`j'] " & " %4.2f B8[`j'] "\\"
		noisily display " & [" %4.2f B3[`j'] ", " %4.2f B4[`j'] "] & [" %4.2f B6[`j'] ", " %4.2f B7[`j'] "] & [" %4.2f B9[`j'] ", " %4.2f B10[`j'] "] \\"
		noisily display " & $ N=$" %4.0f `mrdn`j'' " & $ N=$" %4.0f `diffn`j'' " & $ N=$" %4.0f `diffntrend`j'' "\\[2mm]"
	}
	noisily display "\bottomrule \bottomrule\\[-4mm]"
	noisily display "\multicolumn{4}{p{.5\textwidth}}{\footnotesize MRD estimates use \cite{calonico14} optimal bandwidth implemented with rdrobust in Stata. Sample sizes differ due to variation in optimal bandwidth. "
	noisily display "95\% confidence intervals in brackets; Difference-in-differences standard errors clustered by state."
	noisily display "}"
	noisily display "\end{tabular}"
	noisily display "\end{table}"

	log off

}

/*********************************************
Details on which states drive the effects (Table 3)
*********************************************/

use "MajorityMRD.dta", clear

sort state year
by state: gen tmp = demhouseseatshare if _n == _N
by state: egen tmp2 = max(tmp)

keep state year treat rve dv1_demcontrolhouse dv6_demcontrolhouse tmp2
keep if abs(rve) < .25 & dv6 != .

local N = _N

quietly {
	cap log close
	set linesize 255
	log using "output/obs_table.tex", text replace
	noisily dis "\begin{table}[t]"
	noisily dis "\centering"
	noisily dis "\caption{\label{tab:drivers}{\bf Observations Closest to the Discontinuity.}"
	noisily dis "The estimated disadvantage does not appear to be driven by realignment, given the composition of the sample near the discontinuity.}"
	noisily dis "\begin{tabular}{lcccc}"
	noisily dis "\toprule \toprule"
	noisily dis "State & Year & Dem Maj, $ t $ & Dem Maj, $ t + 6 $ & Dem Share, 2012 \\"
	noisily dis "\midrule"

	forvalues j=1/`N' {
		noisily dis state[`j'] " & " %4.0f year[`j'] " & " dv1[`j'] " & " dv6[`j'] " & " %4.2f tmp2[`j'] "\\"
	}
	noisily dis "\bottomrule \bottomrule"
	noisily dis "\end{tabular}"
	noisily dis "\end{table}"

	log off
}

/*********************************************
Downstream analysis on HOUSE, but Drop South
*********************************************/

use "MajorityMRD.dta", clear

drop if inlist(state,"TX", "OK", "AR", "LA") | inlist(state, "MS", "AL", "TN", "KY") | inlist(state, "FL", "GA", "NC", "SC", "VA", "WV")

rdrobust dv1_demcontrolhouse rve, c(0)
local h = e(h_l) + e(h_r)

matrix B = J(10, 17, .)

keep if dv10_demcontrolhouse != .

forvalues j=1/10 {
	rdrobust dv`j'_demcontrolhouse rve, c(0)
	matrix B[`j', 1] = `j'
	matrix B[`j', 2] = e(tau_cl)
	matrix B[`j', 3] = e(tau_cl) - 1.96*e(se_tau_rb)
	matrix B[`j', 4] = e(tau_cl) + 1.96*e(se_tau_rb)
	local mrdn`j' = e(N_h_l) + e(N_h_r)
	xi: areg dv`j'_demcontrolhouse treat i.year, a(state) cluster(state)
	matrix B[`j', 5] = _b[treat]
	matrix B[`j', 6] = _b[treat] - 1.96*_se[treat]
	matrix B[`j', 7] = _b[treat] + 1.96*_se[treat]
	local diffn`j' = e(N)
	xi: areg dv`j'_demcontrolhouse treat i.year state_trend* year, a(state) cluster(state)
	matrix B[`j', 8] = _b[treat]
	matrix B[`j', 9] = _b[treat] - 1.96*_se[treat]
	matrix B[`j', 10] = _b[treat] + 1.96*_se[treat]
	local diffntrend`j' = e(N)
	rdrobust dv`j'_demhouseseatshare rve, c(0)
	matrix B[`j', 11] = `j'
	matrix B[`j', 12] = e(tau_cl)
	matrix B[`j', 13] = e(tau_cl) - 1.96*e(se_tau_rb)
	matrix B[`j', 14] = e(tau_cl) + 1.96*e(se_tau_rb)
	xi: areg dv`j'_demhouseseatshare treat state_trend* year i.year, a(state) cluster(state)
	matrix B[`j', 15] = _b[treat]
	matrix B[`j', 16] = _b[treat] - 1.96*_se[treat]
	matrix B[`j', 17] = _b[treat] + 1.96*_se[treat]
}

svmat B
keep B*
keep if B1 != .
saveold "temp/downstream_for_r_nosouth.dta", replace

quietly {

set linesize 255

cap log close
	log using "output/mrd_table_nosouth.tex", text replace

	noisily display "\begin{table}[p]"
	noisily display "\centering"
	noisily display "\caption{\label{tab:mrd_nosouth}{\bf Effects of Majority-Party Status on Downstream Electoral Outcomes Excluding Southern States.}"
	noisily display "Both the MRD and the Diff-in-Diff show a pronounced downstream disadvantage.}"
	noisily display "\begin{tabular}{lccc}"
	noisily display "\toprule \toprule"
	noisily display "Terms & MRD & Diff-in-Diff & Diff-in-Diff  \\"
	noisily display " Downstream & & & w/ Trends \\"
	noisily display "\midrule"
	forvalues j=1/10 {
		noisily display " $ k=`j' $ & " %4.2f B2[`j'] " & " %4.2f B5[`j'] " & " %4.2f B8[`j'] "\\"
		noisily display " & [" %4.2f B3[`j'] ", " %4.2f B4[`j'] "] & [" %4.2f B6[`j'] ", " %4.2f B7[`j'] "] & [" %4.2f B9[`j'] ", " %4.2f B10[`j'] "] \\"
		noisily display " & $ N=$" %4.0f `mrdn`j'' " & $ N=$" %4.0f `diffn`j'' " & $ N=$" %4.0f `diffntrend`j'' "\\[2mm]"
	}
	noisily display "\bottomrule \bottomrule\\[-4mm]"
	noisily display "\multicolumn{4}{p{.5\textwidth}}{\footnotesize MRD estimates use \cite{calonico14} optimal bandwidth implemented with rdrobust in Stata.  95\% confidence intervals in brackets; Difference-in-differences standard errors clustered by state."
	noisily display "}"
	noisily display "\end{tabular}"
	noisily display "\end{table}"

	log off

}

/*********************************************
Effects over time
*********************************************/

use "MajorityMRD.dta", clear

matrix B = J(50, 4, .)

local i = 1
forvalues j=1970(10)2010 {
	cap rdrobust dv1_demcontrolhouse rve if year < `j' & year >= `j'-10 , c(0)
	if !_rc {
		matrix B[`i', 1] = `j'
		matrix B[`i', 2] = e(tau_cl)
		matrix B[`i', 3] = e(tau_cl) - 1.96*e(se_tau_rb)
		matrix B[`i', 4] = e(tau_cl) + 1.96*e(se_tau_rb)
	}
	local i = `i' + 1
}

svmat B
keep B*
keep if B1 != .
saveold "temp/over_time.dta", replace

use "MajorityMRD.dta", clear

matrix B = J(50, 4, .)

local i = 1
forvalues j=1970(10)2010 {
	cap rdrobust dv5_demcontrolhouse rve if year < `j' & year >= `j'-10 , c(0)
	if !_rc {
		matrix B[`i', 1] = `j'
		matrix B[`i', 2] = e(tau_cl)
		matrix B[`i', 3] = e(tau_cl) - 1.96*e(se_tau_rb)
		matrix B[`i', 4] = e(tau_cl) + 1.96*e(se_tau_rb)
	}
	local i = `i' + 1
}

svmat B
keep B*
keep if B1 != .
saveold "temp/over_time5.dta", replace


/*********************************************
Downstream analysis on HOUSE for Appendix
Re-do without subsetting
*********************************************/

use "MajorityMRD.dta", clear

rdrobust dv1_demcontrolhouse rve, c(0)
local h = e(h_l) + e(h_r)

matrix B = J(10, 17, .)

forvalues j=1/10 {
	rdrobust dv`j'_demcontrolhouse rve, c(0)
	matrix B[`j', 1] = `j'
	matrix B[`j', 2] = e(tau_cl)
	matrix B[`j', 3] = e(tau_cl) - 1.96*e(se_tau_rb)
	matrix B[`j', 4] = e(tau_cl) + 1.96*e(se_tau_rb)
	local mrdn`j' = e(N_h_l) + e(N_h_r)
	xi: areg dv`j'_demcontrolhouse treat i.year, a(state) cluster(state)
	matrix B[`j', 5] = _b[treat]
	matrix B[`j', 6] = _b[treat] - 1.96*_se[treat]
	matrix B[`j', 7] = _b[treat] + 1.96*_se[treat]
	local diffn`j' = e(N)
	xi: areg dv`j'_demcontrolhouse treat i.year state_trend* year, a(state) cluster(state)
	matrix B[`j', 8] = _b[treat]
	matrix B[`j', 9] = _b[treat] - 1.96*_se[treat]
	matrix B[`j', 10] = _b[treat] + 1.96*_se[treat]
	local diffntrend`j' = e(N)
	rdrobust dv`j'_demhouseseatshare rve, c(0)
	matrix B[`j', 11] = `j'
	matrix B[`j', 12] = e(tau_cl)
	matrix B[`j', 13] = e(tau_cl) - 1.96*e(se_tau_rb)
	matrix B[`j', 14] = e(tau_cl) + 1.96*e(se_tau_rb)
	xi: areg dv`j'_demhouseseatshare treat state_trend* year i.year, a(state) cluster(state)
	matrix B[`j', 15] = _b[treat]
	matrix B[`j', 16] = _b[treat] - 1.96*_se[treat]
	matrix B[`j', 17] = _b[treat] + 1.96*_se[treat]
}

svmat B
keep B*
keep if B1 != .

quietly {

set linesize 255

cap log close
	log using "output/mrd_table_appendix.tex", text replace

	noisily display "\begin{table}[p]"
	noisily display "\centering"
	noisily display "\caption{\label{tab:mrd_app}{\bf Effects of Majority-Party Status on Downstream Electoral Outcomes.}"
	noisily display "Here we remove the sample restriction, allowing the sample to vary with $ k$.  We continue to see a pronounced downstream disadvantage.}"
	noisily display "\begin{tabular}{lccc}"
	noisily display "\toprule \toprule"
	noisily display "Terms & MRD & Diff-in-Diff & Diff-in-Diff  \\"
	noisily display " Downstream & & & w/ Trends \\"
	noisily display "\midrule"
	forvalues j=1/10 {
		noisily display " $ k=`j' $ & " %4.2f B2[`j'] " & " %4.2f B5[`j'] " & " %4.2f B8[`j'] "\\"
		noisily display " & [" %4.2f B3[`j'] ", " %4.2f B4[`j'] "] & [" %4.2f B6[`j'] ", " %4.2f B7[`j'] "] & [" %4.2f B9[`j'] ", " %4.2f B10[`j'] "] \\"
		noisily display " & $ N=$" %4.0f `mrdn`j'' " & $ N=$" %4.0f `diffn`j'' " & $ N=$" %4.0f `diffntrend`j'' "\\[2mm]"
	}
	noisily display "\bottomrule \bottomrule\\[-4mm]"
	noisily display "\multicolumn{4}{p{.5\textwidth}}{\footnotesize MRD estimates use \cite{calonico14} optimal bandwidth implemented with rdrobust in Stata.  95\% confidence intervals in brackets; Difference-in-differences standard errors clustered by state."
	noisily display "}"
	noisily display "\end{tabular}"
	noisily display "\end{table}"

	log off


}

/*********************************************
Eggers plot
*********************************************/

use "MajorityMRD.dta", clear

keep if dv10_demcontrolhouse != .

quietly forvalues i=1/10 {
	matrix B = J(100, 14, .)
	local count = 1
	quietly forvalues j = 10/100 {
		areg dv`i'_demcontrolhouse treat rve rve2 rve3 i.year if abs(rv) < `j', a(state) r
		matrix B[`j', 1] = _b[treat]
		matrix B[`j', 2] = _b[treat] - 1.96*_se[treat]
		matrix B[`j', 3] = _b[treat] + 1.96*_se[treat]
		areg dv`i'_demcontrolhouse treat rve rve_treat i.year if abs(rv) < `j', a(state) r
		matrix B[`j', 4] = _b[treat]
		matrix B[`j', 5] = _b[treat] - 1.96*_se[treat]
		matrix B[`j', 6] = _b[treat] + 1.96*_se[treat]
		areg dv`i'_demcontrolhouse treat rvu rvu2 rvu3 i.year if abs(rve) < `j', a(state) r
		matrix B[`j', 7] = _b[treat]
		matrix B[`j', 8] = _b[treat] - 1.96*_se[treat]
		matrix B[`j', 9] = _b[treat] + 1.96*_se[treat]
		areg dv`i'_demcontrolhouse treat rvu rvu_treat i.year if abs(rve) < `j', a(state) r
		matrix B[`j', 10] = _b[treat]
		matrix B[`j', 11] = _b[treat] - 1.96*_se[treat]
		matrix B[`j', 12] = _b[treat] + 1.96*_se[treat]
		matrix B[`j', 13] = `j'
		matrix B[`j', 14] = e(N)
		local count = `count' + 1
	}

	preserve
	svmat B
	keep if B1 != .
	keep B*
	rename B1 est3
	rename B2 lower3
	rename B3 upper3
	rename B4 est1
	rename B5 lower1
	rename B6 upper1
	rename B7 este3
	rename B8 lowere3
	rename B9 uppere3
	rename B10 este1
	rename B11 lowere1
	rename B12 uppere1
	rename B13 x
	keep if B14 > 50
	saveold "temp/specification_graph`i'.dta", replace

	restore

}

/*********************************************
Downstream other offices
*********************************************/

use "MajorityMRD.dta", clear

matrix B = J(10, 11, .)

forvalues j=1/10 {
	rdrobust dv`j'_demcontrolhouse rve, c(0)
	matrix B[`j', 1] = `j'
	matrix B[`j', 2] = e(tau_cl)
	matrix B[`j', 3] = e(tau_cl) - 1.96*e(se_tau_rb)
	matrix B[`j', 4] = e(tau_cl) + 1.96*e(se_tau_rb)
	rdrobust dv`j'_demcontrolsenate rve, c(0)
	matrix B[`j', 5] = e(tau_cl)
	matrix B[`j', 6] = e(tau_cl) - 1.96*e(se_tau_rb)
	matrix B[`j', 7] = e(tau_cl) + 1.96*e(se_tau_rb)
	rdrobust dv`j'_demgov rve,  c(0)
	matrix B[`j', 8] = `j'
	matrix B[`j', 9] = e(tau_cl)
	matrix B[`j', 10] = e(tau_cl) - 1.96*e(se_tau_rb)
	matrix B[`j', 11] = e(tau_cl) + 1.96*e(se_tau_rb)
}

svmat B
keep B*
keep if B1 != .
saveold "temp/downstream_other_offices_for_r.dta", replace

/*********************************************
Effects across professionalization
*********************************************/

use "MajorityMRD.dta", clear

matrix B = J(10, 14, .)

keep if dv10_demcontrolhouse != .

gl cutoff = 30

forvalues j=1/10 {
	rdrobust dv`j'_demcontrolhouse rve if squire_rank > $cutoff, c(0)
	matrix B[`j', 1] = `j'
	matrix B[`j', 2] = e(tau_cl)
	matrix B[`j', 3] = e(tau_cl) - 1.96*e(se_tau_rb)
	matrix B[`j', 4] = e(tau_cl) + 1.96*e(se_tau_rb)
	xi: areg dv`j'_demcontrolhouse treat i.year if squire_rank > $cutoff, a(state) cluster(state)
	matrix B[`j', 5] = _b[treat]
	matrix B[`j', 6] = _b[treat] - 1.96*_se[treat]
	matrix B[`j', 7] = _b[treat] + 1.96*_se[treat]
	rdrobust dv`j'_demhouseseatshare rve, c(0)
	matrix B[`j', 8] = `j'
	matrix B[`j', 9] = e(tau_cl)
	matrix B[`j', 10] = e(tau_cl) - 1.96*e(se_tau_rb)
	matrix B[`j', 11] = e(tau_cl) + 1.96*e(se_tau_rb)
	xi: areg dv`j'_demhouseseatshare treat i.year if squire_rank > $cutoff, a(state) cluster(state)
	matrix B[`j', 12] = _b[treat]
	matrix B[`j', 13] = _b[treat] - 1.96*_se[treat]
	matrix B[`j', 14] = _b[treat] + 1.96*_se[treat]
}

svmat B
keep B*
keep if B1 != .
saveold "temp/downstream_squire_for_r.dta", replace

/*********************************************
Bootstrap Results (figures and table)
*********************************************/

use "data/BootstrapResults.dta", clear
keep if chamber=="house"
drop chamber
merge 1:1 state year using "MajorityMRD.dta"
drop _merge

replace AverageP = . if rve==.
gen rvBoostrap = .
sum AverageP if treat==1
local min= r(min)
replace rvBoostrap = AverageP - `min' +0.001 if treat==1

sum AverageP if treat==0
local max= r(max)
replace rvBoostrap = AverageP - `max' -0.001  if treat==0
bysort treat: sum rvB
gen seatshare = lhd/leg_size

spearman  rve rv rvu rvBoostrap, star(0.01) pw
mat m = r(Rho)
mat n = r(P)

quietly {

set linesize 255

cap log close
	log using "output/rv_correlation.tex", text replace

	noisily display "\begin{table}[p]"
	noisily display "\centering"
	noisily display "\caption{\label{tab:rv_corr}{\bf Spearman's Rank Correlations between Running Variables.}}"
	noisily display "\begin{tabular}{l cccc}"
	noisily display "\toprule \toprule"
	noisily display " & Euclid & Manhat & Uniform & Bootstrap \\"
	noisily display " Euclid & " %4.3f m[1,1] " &  & & \\"
	noisily display " 		 & (" %4.3f n[1,1] ") &  & & \\[2mm]"
	noisily display " Manhat & "  %4.3f m[2,1] " & " %4.3f m[2,2] " & & \\"
	noisily display " 		 & ("  %4.3f n[2,1] ") & (" %4.3f n[2,2] ") & & \\[2mm]"
	noisily display " Uniform & "  %4.3f m[3,1] " & " %4.3f m[3,2] " & " %4.3f m[3,3] " & \\"
	noisily display " 		 & ("  %4.3f n[3,1] ") & (" %4.3f n[3,2] ") & (" %4.3f n[3,3] ") & \\[2mm]"
	noisily display " Bootstrap & "  %4.3f m[4,1] " & " %4.3f m[4,2] " & "  %4.3f m[4,3] " & "  %4.3f m[4,4] " \\"
	noisily display " 			& ("  %4.3f n[4,1] ") & (" %4.3f n[4,2] ") & ("  %4.3f n[4,3] ") & ("  %4.3f n[4,4] ") \\[2mm]"
	noisily display "\bottomrule \bottomrule\\[-4mm]"
	noisily display "\end{tabular}"
	noisily display "\end{table}"

	log off

}

hist rvB, graphregion(color(white)) xtitle("RV Boostrap")  bcolor(blue)  saving("figures/rvB", replace)
hist rve, graphregion(color(white)) xtitle("RV Euclidian")  bcolor(red)  saving("figures/rvE", replace)
hist rvu, graphregion(color(white)) xtitle("RV Uniform Swing")  bcolor(green) saving("figures/rvU", replace)
hist rv, graphregion(color(white)) xtitle("RV Manhattan") bcolor(purple) saving("figures/rv", replace)

gr combine "figures/rvB.gph" "figures/rvE.gph" "figures/rv.gph" "figures/rvU.gph" , graphregion(margin(zero)) iscale(1)
graph export "figures/histograms.pdf", replace

matrix B = J(10, 14, .)

forvalues j=1/6 {
	rdrobust dv`j'_demcontrolhouse rve, c(0)
	matrix B[`j', 1] = `j'
	matrix B[`j', 2] = e(tau_cl)
	matrix B[`j', 3] = e(tau_cl) - 1.96*e(se_tau_rb)
	matrix B[`j', 4] = e(tau_cl) + 1.96*e(se_tau_rb)
	local mrdn`j' = e(N_h_l) + e(N_h_r)
	rdrobust dv`j'_demcontrolhouse rvB, c(0) h(.4)
	matrix B[`j', 5] = e(tau_cl)
	matrix B[`j', 6] = e(tau_cl) - 1.96*e(se_tau_rb)
	matrix B[`j', 7] = e(tau_cl) + 1.96*e(se_tau_rb)
	local diffn`j' = e(N_h_l) + e(N_h_r)
}

svmat B
keep B*
keep if B1 != .

quietly {

set linesize 255

cap log close
	log using "output/BootstrapResults.tex", text replace

	noisily display "\begin{table}[p]"
	noisily display "\centering"
	noisily display "\caption{\label{tab:bootstrap_results}{\bf Effects of Majority-Party Status on Downstream Electoral Outcomes.}}"
	noisily display "\begin{tabular}{lcc}"
	noisily display "\toprule \toprule"
	noisily display "Terms Downstream & Euclidian RV & Boostrap RV  \\"
	noisily display "\midrule"
	forvalues j=1/6 {
		noisily display " $ k=`j' $ & " %4.2f B2[`j'] " & " %4.2f B5[`j'] "\\"
		noisily display " & [" %4.2f B3[`j'] ", " %4.2f B4[`j'] "] & [" %4.2f B6[`j'] ", " %4.2f B7[`j'] "] \\"
		noisily display " & $ N=$" %4.0f `mrdn`j'' " & $ N=$" %4.0f `diffn`j'' "\\[2mm]"
	}
	noisily display "\bottomrule \bottomrule\\[-4mm]"
	noisily display "\multicolumn{3}{p{.6\textwidth}}{\footnotesize All estimates use Calonico et. al. optimal bandwidth implemented with rdrobust in Stata.  95\% confidence intervals in brackets."
	noisily display "}"
	noisily display "\end{tabular}"
	noisily display "\end{table}"

	log off


}
