* PROGRAM:      bootstrap_prep.do
* AUTHOR:       Alex Fouirnaies, James Feigenbaum, Andy Hall
* INFILE:      MajorityMRD.dta
*************************************************************************

clear
program drop _all

/*********************************************
set the path
*********************************************/


** to run this locally, set the path global to the majority_advantage folder

local dir : pwd
if (regexm("`dir'", "feigenbaum")) {
	gl path = "C:/Users/jfeigenbaum/Dropbox/Research/majority_advantage/replication"
}
if (regexm("`dir'", "jjf")) {
	gl path = "D:/Dropbox/Research/majority_advantage/replication/zip/replication_files"
}
if (regexm("`dir'", "hall")) {
	gl path = "~/Dropbox/majority_advantage/replication"
}
if (regexm("`dir'", "alex")) {
	gl path = "~/Dropbox/research/majority_advantage/replication"
}

cd "$path"

/*********************************************
Prepare data for bootstrap results
*********************************************/

clear
set seed 12345
set maxvar 20000
use "temp/data_for_resampling.dta", replace //this dataset is created in line 113 of data_prep.do

/* remove these comments to rerun the bootstrap (overnight)

*repeat the script in the loop 10,000 times
forval j=1/10000 {
	*draw a sample of 500 voters in each district. The probability that a given voter votes democratic is equal to the democratic vote share in the district.
	qui forval i=1/500 {
		gen randomnumber`i' = runiform(0, 100) // generate random number uniformly distributed U[0,100]
		gen demvote`i' = randomnumber`i'< demwinmargin + 50 if  demwinmargin!=. // if the random number is in the interval [0,demvtsh], consider it a democratic vote.
	}
	drop randomnumber*

	egen totaldemvotes= rowtotal(demvote*) //sum up total number of democratic votes
	gen demwinseat_simulation = totaldemvotes>250 // democrats win the seat if they win more than 50% of the votes
	drop demvote* totaldemvotes

	*calculate the dem seat share for each session year
	bysort state lower year: egen seatshare_simulation=mean(demwinseat_simulation)
	*determine whether dem's won the majority
	gen demmajority`j' = seatshare_simulation>.5
	drop demwinseat_simulation seatshare_simulation
	*di `j'
}
egen AverageP = rowmean(demmajority*)
collapse (mean) AverageP demwinseat ,by(state lower year)
rename demwinseat SeatShare
gen chamber="house" if lower==1

saveold "data/BootstrapResults.dta", replace

*/
