* PROGRAM :			majadv.do
* AUTHOR :			Alex Fouirnaies,James Feigenbaum, Andy Hall
* INFILE(S) :		Partisan_Balance_For_Use2011_06_09b.xlsx, state_leg_party_div_1950_2010.dta, klarner_data.dta, squire.dta, stateabbrev.dta, fips_codes.dta
* OUTFILE(S) :		MajorityMRD.dta , (majority_merge.dta is a temp file)
* DATE WRITTEN :	8 April 2014
*************************************************************************

clear
program drop _all

local dir : pwd
if (regexm("`dir'", "feigenbaum")) {
	gl path = "C:/Users/jfeigenbaum/Dropbox/Research/majority_advantage/replication/zip/replication_files"
}
if (regexm("`dir'", "jjf")) {
	gl path = "D:/Dropbox/Research/majority_advantage/replication/zip/replication_files"
}
if (regexm("`dir'", "hall")) {
	gl path = "~/Dropbox/majority_advantage/replication"
}
if (regexm("`dir'", "alexander")) {
	gl path = "~/Dropbox/research/majority_advantage/replication"
}

cd "$path"
*************************************************************************

/*********************************************
load Klarner data
*********************************************/

use "data/SLERs1967to2014_20150818_Extra_Vars_Updated.dta", clear

*rename Klarner's variables
egen districtidentifier= concat(v08 v09 v10a v10b v10c)

rename v02 state
rename v05 year
rename v07 lower
rename v09 dist
*rename v11 districtidentifier
rename v12 districttype
rename v13 numberofwinners
rename v16 electiontype
rename v18 CandId
rename v21 party
rename v23 candidatevotes
rename v24 win
*rename v30 demvote
*rename v31 repvote
*rename v32 othervote
*rename v36 vtsh
*rename v37 winmargin
rename v19 CandName
replace lower=1 if lower==9
replace lower=0 if lower==8

**drop 2014 data (the 2014 data is still incomplete and not officially released by Klarner).
drop if year==2014

**keep only general elections (drop primary and special elections) and lower House elections
keep if electiontype=="G" & lower==1
** if multimember districts or staggered elections: drop all obs in a state-chamber-year
gen multimember = 1 if districttype == 3 | districttype==6 | districttype==9 | districttype==10
replace multimember= 0 if districttype ==1 | districttype ==2 | districttype ==4 |districttype ==5|districttype ==7|districttype ==8  // 1. Single-Member District 2. Multimember District with Positions / Posts 3. Multimember District Free-for-All 4. Multimember District Alternating Years (Staggered Terms), but only one seat up in that year. 5. Multimember District Alternating Years (Staggered Terms), but multiple seats up in that year, with posts. 6. Multimember District Alternating Years (Staggered Terms), but multiple seats up in that year, without posts. 7. Floterial District (Single-Member) 8. Floterial District (Multimember with Positions / Posts) 9. Floterial District (Multimember Free-for-All) 10. Multimember district with cumulative voting (this only includes the Illinois House in 1980 and before).
bysort state year: egen maxmember = max(multimember)
keep if maxmember==0
drop multimember maxmember

*sort state lower year districtidentifier  CandId candidatevotes
*bysort CandId year: egen totalvotes=total(candidatevotes)
*br if year==2014

gen d = (party==100)
gen r = (party==200)
bysort CandId year: egen dem= max(d)
bysort CandId year: egen rep= max(r)

gen Party = "O"
replace Party = "D" if dem==1
replace Party = "R" if rep==1

order state lower dist year districtidentifier party v20 CandName candidatevotes  year

*sum votes by candidates in each contest (some years the rows in the Klarner data pertains to counties in other it pertains to districts. Collapse so everything is total votes to a candidate)
collapse (sum) candidatevotes (first) state lower  districtidentifier , by(  CandId Party year)

* Keep only top candidate for each party
sort state lower  districtidentifier CandId Party year candidatevotes
collapse (max) candidatevotes  , by( state lower  districtidentifier Party year)

*reshape such each row corresponds to a district in a given election
reshape wide candidatevotes, i( state lower districtidentifier year) j(Party) string
*replace missing votes with zeros
foreach i in D R O {
	replace candidatevotes`i' =0 if candidatevotes`i'==.
}

*generate dem win margin
gen demwinmargin = .
replace demwinmargin = 100*[candidatevotesD / (candidatevotesR + candidatevotesD)] - 50 if candidatevotesR>= candidatevotesO
replace demwinmargin = 100*[candidatevotesD / (candidatevotesO + candidatevotesD)] - 50 if candidatevotesR< candidatevotesO
gen demwinseat = demwinmargin>0 & demwinmargin!=.

*merge with outcome data
merge m:1 state year using "data/electoral_outcomes.dta"
keep if _merge==3
drop _merge

sort year state districtidentifier

*save the data we use in the bootstrap
save "temp/data_for_resampling.dta", replace

**merge in Squire data
sort state
merge m:1 state using "data/squire.dta"
keep if _merge==3
drop _merge

/*********************************************
generate distance metrics
*********************************************/

*** dropping cases where demwinmargin == 0
*** these are actual tied elections, not sure how they were decided
*drop if demwinmargin == 0

*** drop tied legislatures
*drop if lhd == lhr

gen temp = abs(demwinmargin)

egen rank = rank(temp), by(state year demwinseat) unique
**ties (we both win by the same X) are broken randomly by rank()
drop temp

rename lht leg_size

**there are a TON of even numbered legislatures
**mod(leg_size,2) has more 0s (evens) than 1s (odds)...
**I'm going to assume that dems need 50% + 1 seat...
**but this might be wrong
gen seats_for_majority = ceil((leg_size + 1)/ 2)

gen seats_to_flip = lhd - seats_for_majority
** at 0, dems have a majority, but just barely
** at -1 they'd need one more seat to get the majority
** at 1, dems have a cushion... they could lose one seat and retain the majority


**Absolute distance calculations:
**total vote shares for the dems to lose majority
egen temp1 = sum(demwinmargin) if rank <= (seats_to_flip + 1) & demwinseat == 1 & seats_to_flip >= 0, by(state year)

**total vote shares for the dems to win majority
egen temp2 = sum(demwinmargin) if rank <= abs(seats_to_flip) & demwinseat == 0 & seats_to_flip < 0, by(state year)

egen temp = rowmax(temp*)

egen running_var = max(temp), by(state year)

**Euclidian distance calculations:
**the squared demmargin is used to calculated the euclidian distance
gen demwinmargin_sq = demwinmargin^2

** total squared vote shares for the dems to lose majority
egen euclid_temp1 = sum(demwinmargin_sq) if rank <= (seats_to_flip + 1) & demwinseat == 1 & seats_to_flip >= 0, by(state year)

**total vote shares for the dems to win majority
egen euclid_temp2 = sum(demwinmargin_sq) if rank <= abs(seats_to_flip) & demwinseat == 0 & seats_to_flip < 0, by(state year)

**take square root to calculate euclidian distance.
replace euclid_temp1 = sqrt(euclid_temp1)
replace euclid_temp2 = - sqrt(euclid_temp2) //negative b/c dems are seats short of winning a majority

egen euclid_temp = rowmax(euclid_temp*)
egen running_euclid = max(euclid_temp), by(state year)

**Uniform partisan swing distance calculations:
gen ups_temp = demwinmargin if seats_to_flip == rank * (sign(seats_to_flip))
replace ups_temp = . if (sign(ups_temp) != sign(seats_to_flip))
egen running_ups = max(ups_temp), by(state year)

**seat share running var distance calculations:
gen running_seatshare = demhouseseatshare - 50

drop *temp*

contract state fips year treat leg_size running_var running_euclid running_seatshare running_ups dv* seats_to_flip lhd lhr squire* dv* lag* dem_lower dem_upper demhouseseatshare demsenateseatshare

rename _freq number_of_elections
**drop obs where some uncontested elections are not in the Klarner data
drop if number_of_elections<leg_size

**** Interactions and polynomials
gen rve = running_euclid
gen rve_treat = rve * treat
gen rve2 = rve^2
gen rve3 = rve^3

gen rvs = running_seatshare
gen rvs2 = rvs^2
gen rvs3 = rvs^3
gen rvs_treat = rvs * treat

gen rvu = running_ups
gen rvu2 = running_ups^2
gen rvu3 = running_ups^3
gen rvu_treat = rvu * treat

gen rv = running_var
gen rv_treat = rv*treat
gen rv2 = rv^2
gen rv3 = rv^3

*** abh: still two cases where treat == 1 but running_var < 0
drop if treat == 1 & running_var < 0

preserve

**** Merge in US House data for precision gain
use "data/tmp_rdd_us_house_postwar.dta", clear

collapse (mean) rv, by(state year)
rename rv house_average
sort state year
save "temp/house_for_merge.dta", replace

restore
sort state year
merge state year using "temp/house_for_merge.dta"

drop if _merge == 2
drop _merge

**** Merge in polarization data
preserve
use "data/polar_merge.dta", clear
keep if lower == 1
drop lower
sort state year
save "temp/tmp_polar_merge.dta", replace

restore

sort state year
merge 1:1 state year using "temp/tmp_polar_merge.dta"
drop if _merge == 2
drop _merge

order state fips year treat rv* dv*

tabulate state, generate(state_dummy)
egen tmp = group(state)
sum tmp
local m = r(max)
forvalues j=1/`m' {
	gen state_trend`j' = year * state_dummy`j'
}
drop tmp

saveold MajorityMRD, replace
