#graphs.R
# This file creates all the graphs included in FFH 2016, QJPS


### override default mgp in par to make better ticks
par.gh <- function(..., mgp=c(0,.05,.05)) {
  par(..., mgp=mgp)
}

### Michael Gill's brilliant function to make transparent colors
makeTransparent<-function(someColor, alpha)
{
  newColor<-col2rgb(someColor)
  apply(newColor, 2, function(curcoldata){rgb(red=curcoldata[1], green=curcoldata[2],
                                              blue=curcoldata[3],alpha=alpha, maxColorValue=255)})
}


### function to produce nice plots
### preserves most defaults through "..."
### defaults labels to blank, axes to missing, makes points look nice
plot.gh <- function(..., xlab="", ylab="", xaxt="n", yaxt="n", pch=21, bg="gray80", col="black",bor_col="white", x_seq = NULL,  y_seq = NULL, bty=NULL, rect_col="gray90", do_axes=NULL, do_seq=T, outer.box=F, outer.box.col="black", grid_col="white", point.size=1.3, remove.axis=F) {
  plot(..., xlab=xlab, ylab=ylab, xaxt=xaxt, yaxt=yaxt, pch=pch, bg=bg,  bty="n")
  rect(par("usr")[1], par("usr")[3], par("usr")[2], par("usr")[4], col = rect_col, border= bor_col)
  # Draw sequences in background
  if(do_seq!=F){
    grid(col=grid_col, lty=2)
  }
  # Add axis
  if (!remove.axis) {
    axis(side=1,lwd=0, lwd.ticks=1, tck=-0.01, col="white", col.axis="gray20", cex.axis=.8)
    axis(side=2,lwd=0, lwd.ticks=1, tck=-0.01, las=1, col="white", col.axis="gray20", cex.axis=.8)
  }
  # Add points
  points(...,pch=21, bg=bg, col=col, lwd=1.5, cex=point.size)
  # Y/N add box around plot
  if(outer.box==T){
    box(col= outer.box.col)	
  }
}




# load libraries
library(magrittr)
library(data.table)
library(readstata13)
library(foreign)
library(readstata13)

setwd("D:/Dropbox/Research/majority_advantage/replication")

##### Downstream graph
data <- read.dta13("temp/downstream_for_r.dta")
e <- .1
pdf(file="figures/effects.pdf", width=10, height=7)
par.gh()
plot.gh(x = 1:10, y=data$B2, xlim=c(0,11), ylim=c(-.7,.6), col="gray90", bg="gray90", xlab="", ylab="", cex.axis=1.2, yaxt="n", remove.axis=T)
abline(h=0, col="black", lty=2)
segments(x0=(1-e):(10-e), x1=(1-e):(10-e), y0=data$B3, y1=data$B4, col="gray60", lwd=3, lend=2)
points(x = (1-e):(10-e), y=data$B2, pch=21, cex=1.6, col="black", bg="gray50")
segments(x0=(1+e):(10+e), x1=(1+e):(10+e), y0=data$B6, y1=data$B7, col="gray60", lwd=3, lend=2)
points(x = (1+e):(10+e), y=data$B5, pch=17, col="cadetblue4", cex=1.6)
legend("topleft", pch=c(16, 17), col=c("black", "cadetblue4"), c("Multidimensional RD", "Difference-in-Differences"), cex=1.4, bty="n")
axis(side=2, las=1, cex.axis=1.4, lwd=0)
mtext(side=2, "Estimated Effect on Probability of Majority", line=2.7, cex=1.4)
axis(side=1, lwd=0, cex.axis=1.4)
mtext(side=1, line=1.8, cex=1.4, "Terms Downstream")
dev.off()

### downstream graph with seat share

# e <- .1
# plot(x = 1:10, y=data$B2, xlim=c(0,11), ylim=c(-10,10), col="white", xlab="Terms Downstream", ylab="Estimated Effect on Seat Share")
# abline(h=0, col="red", lty=2)
# segments(x0=(1-e):(10-e), x1=(1-e):(10-e), y0=data$B10, y1=data$B11, col="gray80", lwd=2)
# points(x = (1-e):(10-e), y=data$B9, pch=16, cex=1.3)
# segments(x0=(1+e):(10+e), x1=(1+e):(10+e), y0=data$B13, y1=data$B14, col="gray60", lwd=2)
# points(x = (1+e):(10+e), y=data$B12, pch=17, col="cadetblue4", cex=1.2)
# legend("topright", pch=c(16, 17), col=c("black", "cadetblue4"), c("Multidimensional RD", "Difference-in-Differences"))


### effect over time

data.time <- read.dta13("temp/over_time.dta")
data.time$B1 <- data.time$B1 - 10

pdf(file="figures/overtime.pdf", height=5, width=8)
plot(x=data.time$B1, y=data.time$B2, ylim=c(-1,1), col="white", xaxt="n", xlab="Decade", ylab="Majority-Party Effect", yaxt="n")
abline(h=0, lty=1, col="gray50")
lines(x=data.time$B1, y=data.time$B3, col="gray10", lty=2)
lines(x=data.time$B1, y=data.time$B4, col="gray10", lty=2)
lines(x=data.time$B1, y=data.time$B2, lwd=3, type="o", pch=16)
axis(side=1, at=c(1970, 1980, 1990, 2000), labels=c(1970, 1980, 1990, 2000))
axis(side=2, las=1)
dev.off()

data.time <- read.dta13("temp/over_time5.dta")
data.time$B1 <- data.time$B1 - 10

# can restrict CI to lie between -1 and 1
data.time$B3[data.time$B3 < -1] <- -1

pdf(file="figures/overtime5.pdf", height=5, width=8)
plot(x=data.time$B1, y=data.time$B2, ylim=c(-1,1), col="white", xaxt="n", xlab="Decade", ylab="Majority-Party Effect", yaxt="n")
abline(h=0, lty=1, col="gray50")
lines(x=data.time$B1, y=data.time$B3, col="gray10", lty=2)
lines(x=data.time$B1, y=data.time$B4, col="gray10", lty=2)
lines(x=data.time$B1, y=data.time$B2, lwd=3, type="o", pch=16)
axis(side=1, at=c(1970, 1980, 1990, 2000), labels=c(1970, 1980, 1990, 2000))
axis(side=2, las=1)
dev.off()


##### Downstream squire graph
data <- read.dta13("temp/downstream_squire_for_r.dta")
e <- .1
pdf(file="figures/squire_effects.pdf", width=10, height=7)
par.gh()
plot.gh(x = 1:10, y=data$B2, xlim=c(0,11), ylim=c(-1.3,1), col="gray90", bg="gray90", xlab="", ylab="", cex.axis=1.2, yaxt="n", remove.axis=T)
abline(h=0, col="black", lty=2)
segments(x0=(1-e):(10-e), x1=(1-e):(10-e), y0=data$B3, y1=data$B4, col="gray60", lwd=3, lend=2)
points(x = (1-e):(10-e), y=data$B2, pch=21, cex=1.6, col="black", bg="gray50")
segments(x0=(1+e):(10+e), x1=(1+e):(10+e), y0=data$B6, y1=data$B7, col="gray60", lwd=3, lend=2)
points(x = (1+e):(10+e), y=data$B5, pch=17, col="cadetblue4", cex=1.6)
legend("topleft", pch=c(16, 17), col=c("black", "cadetblue4"), c("Multidimensional RD", "Difference-in-Differences"), cex=1.4, bty="n")
axis(side=2, las=1, cex.axis=1.4, lwd=0)
mtext(side=2, "Estimated Effect on Probability of Majority", line=2.7, cex=1.4)
axis(side=1, lwd=0, cex.axis=1.4)
mtext(side=1, line=1.8, cex=1.4, "Terms Downstream")
dev.off()

##### balancing graph
data <- read.dta13("temp/downstream_other_offices_for_r.dta")
e <- .1
pdf(file="figures/balancing.pdf", width=10, height=7)
plot(x = 1:10, y=data$B9, xlim=c(0,11), ylim=c(-.6,.6), col="white", xlab="Terms Downstream", ylab="Estimated Effect on Probability of Majority", yaxt="n", cex.axis=1.2)
abline(h=0, col="red", lty=2)
segments(x0=(1-e):(10-e), x1=(1-e):(10-e), y0=data$B10, y1=data$B11, col="gray80", lwd=5, lend=2)
points(x = (1-e):(10-e), y=data$B9, pch=16, cex=1.6)
segments(x0=(1+e):(10+e), x1=(1+e):(10+e), y0=data$B6, y1=data$B7, col="gray80", lwd=5, lend=2)
points(x = (1+e):(10+e), y=data$B5, pch=17, col="cadetblue4", cex=1.6)
axis(side=2, las=1, cex.axis=1.2)
legend("topright", pch=c(16, 17), col=c("black", "cadetblue4"), c("Governor", "State Senate"), cex=1.4)
dev.off()



##### RDD plot

pdf(file="figures/RDDs_win.pdf", height=6, width=7)
par(mfrow=c(3,3), oma=c(3,3,3,3), mar=c(2,2,.3,.3))
min <- -50
max <- -min
for (j in 1:9) {
	rd.data <- read.dta13(paste("temp/rdd_plot_win", j, ".dta", sep=""))

	count <- 1
	bin.size <- 2
	binx.left <- vector(length=length(seq(min, 0, bin.size)))
	biny.left <- vector(length=length(binx.left))
	last <- min
	for(i in seq(min, 0, bin.size)) {
		biny.left[count] <- mean(rd.data$dv[rd.data$rv >= i-bin.size & rd.data$rv < i], na.rm=T)
		binx.left[count] <- (i+last)/2
		last <- i
		count <- count + 1
	}

	count <- 1
	bin.size <- 2
	binx.right <- vector(length=length(seq(1,max, bin.size)))
	biny.right <- vector(length=length(binx.right))
	last <- 0
	for(i in seq(1,max, bin.size)) {
		biny.right[count] <- mean(rd.data$dv[rd.data$rv >= i-bin.size & rd.data$rv < i], na.rm=T)
		binx.right[count] <- (i+last)/2
		last <- i
		count <- count + 1
	}

	reg1 <- lm(rd.data$dv[rd.data$rv < 0] ~ rd.data$rv[rd.data$rv < 0])
	reg2 <- lm(rd.data$dv[rd.data$rv > 0] ~ rd.data$rv[rd.data$rv > 0])

	fits1 <- reg1$coefficients[1] + reg1$coefficients[2] * rd.data$rv[rd.data$rv<0]
	fits2 <- reg2$coefficients[1] + reg2$coefficients[2] * rd.data$rv[rd.data$rv>0]

	plot(x=rd.data$rv, y=rd.data$dv, col="white", xlab="", yaxt="n", ylab="", cex.lab=1.5, cex.axis=.9, main="", cex.main=1.8, cex.axis=1.4, xaxt="n", ylim=c(0, 1))
	points(x=rd.data$rv, y=rd.data$dv, pch=1, col="gray60", cex=.6)
	points(x=binx.left, y=biny.left, pch=16, col="black", cex=1.1)
	points(x=binx.right, y=biny.right, pch=16, col="black", cex=1.1)
	lines(x=rd.data$rv[rd.data$rv<0], y=fits1, lwd=2, col="cadetblue3")
	lines(x=rd.data$rv[rd.data$rv>0], y=fits2, lwd=2, col="cadetblue3")
	if (j==1 | j==4 | j==7) {
	axis(side=2, las=1, cex.axis=.9, at=seq(-1, 1, .5), labels=seq(-1, 1, 0.5), cex.axis=1.4)
	mtext(side=2, line=3.5, "Dem Majority")
	}
	abline(v=0, col="gray20", lty=2)
	if (j >= 7) {
		axis(side=1, cex.axis=1.4)
		#mtext(side=1, line=2.5, "Distance to Majority")
	}
if (j==1) mtext(side=3, "1 Term Downstream", font=1, line=.2)
else mtext(side=3, paste(j, " Terms Downstream", sep=""), font=1, line=.2)}
mtext(side=1, outer=T, "Distance to Majority", line=1)
dev.off()



####### Eggers plot

pdf(file="figures/spec.pdf")
par(mfrow=c(3,3), oma=c(3,3,3,3), mar=c(1,1,1.4,1))
for (i in 1:9) {
data <- read.dta13(paste("temp/specification_graph", i, ".dta", sep=""))

if (i < 4) {
	min <- -.5
	max <- .5
}
if (i == 4 | i == 5 | i == 6) {
	min <- -.5
	max <- .5
}
if (i > 6) {
	min <- -.5
	max <- .5
}

plot(x=data$x, y=data$est3, col="white", xlab="", ylab="", xaxt="n", yaxt="n",ylim=c(min, max), xaxt="n")
abline(h=0, lty=2)
lines(x=data$x, y=data$est3, col="darkred")
lines(x=data$x, y=data$est1, col="darkred", lty=2)
lines(x=data$x, y=data$este3, col="darkgreen")
lines(x=data$x, y=data$este1, col="darkgreen", lty=2)
if (i==1) axis(side=2, las=1, at=seq(-.5, .5, .5))
if (i==4) axis(side=2, las=1, at=seq(-.5, .5, .5))
if (i==7) axis(side=2, las=1, at=seq(-.5, .5, .5))

if (i>6) axis(side=1)

if (i==1) mtext(side=3, "1 Term Downstream", font=1, line=.2)
else mtext(side=3, paste(i, " Terms Downstream", sep=""), font=1, line=.2)

if (i==3) {
legend("topright", col=c("darkred", "darkgreen"), c("Euclidean", "Uniform-Swing"), fill=c("darkred", "darkgreen"), cex=.7)
legend("topleft", lty=c(1,2), c("Cubic", "Local Linear"), cex=.7)
}
}
mtext(side=1, outer=T, line=2, "Bandwidth", cex=.8)
mtext(side=2, outer=T, line=2, "Estimate", cex=.8)

dev.off()
